@@ -148,21 +148,23 @@ void Module::loadSoftware()
                                                           KConfig::NoGlobals);
     KConfigGroup cg = KConfigGroup(config, "General");
 
-    const QString logoPath = cg.readEntry("LogoPath", QString());
-    QPixmap logo;
+    OSRelease os;
+
+    QString logoPath = cg.readEntry("LogoPath", os.logo);
     if (logoPath.isEmpty()) {
-        logo = QIcon::fromTheme(QStringLiteral("start-here-kde")).pixmap(128, 128);
-    } else {
-        logo = QPixmap(logoPath);
+        logoPath = QStringLiteral("start-here-kde");
     }
+    const QPixmap logo = QIcon::fromTheme(logoPath).pixmap(128, 128);
     ui->logoLabel->setPixmap(logo);
 
-    OSRelease os;
     // We allow overriding of the OS name for branding purposes.
     // For example OS Ubuntu may be rebranded as Kubuntu. Also Kubuntu Active
     // as a product brand is different from Kubuntu.
     const QString distroName = cg.readEntry("Name", os.name);
-    const QString versionId = cg.readEntry("Version", os.versionId);
+    const QString osrVersion = cg.readEntry("UseOSReleaseVersion", false)
+            ? os.version
+            : os.versionId;
+    const QString versionId = cg.readEntry("Version", osrVersion);
     const QString distroNameVersion = QStringLiteral("%1 %2").arg(distroName, versionId);
     ui->nameVersionLabel->setText(distroNameVersion);
 
@@ -171,7 +173,7 @@ void Module::loadSoftware()
     labelsForClipboard << qMakePair(dummyDistroDescriptionLabel, ui->nameVersionLabel);
     englishTextForClipboard += QStringLiteral("Operating System: %1\n").arg(distroNameVersion);
 
-    const QString variant = cg.readEntry("Variant", QString());
+    const QString variant = cg.readEntry("Variant", os.variant);
     if (variant.isEmpty()) {
         ui->variantLabel->hide();
     } else {
